@@ -355,7 +355,7 @@ def cosine_beta_schedule(timesteps, s = 0.008):
     """
     steps = timesteps + 1
     x = torch.linspace(0, timesteps, steps, dtype = torch.float64)
-    alphas_cumprod = torch.cos(((x / timesteps) + s) / (1 + s) * torch.pi * 0.5) ** 2
+    alphas_cumprod = torch.cos(((x / timesteps) + s) / (1 + s) * math.pi * 0.5) ** 2
     alphas_cumprod = alphas_cumprod / alphas_cumprod[0]
     betas = 1 - (alphas_cumprod[1:] / alphas_cumprod[:-1])
     return torch.clip(betas, 0, 0.999)
@@ -590,7 +590,7 @@ class Trainer(object):
         gradient_accumulate_every = 2,
         amp = False,
         step_start_ema = 2000,
-        update_ema_every = 10,
+        ema_update_every = 10,
         save_and_sample_every = 1000,
         results_folder = './results',
         augment_horizontal_flip = True
@@ -599,8 +599,7 @@ class Trainer(object):
         self.image_size = diffusion_model.image_size
 
         self.model = diffusion_model
-        self.ema = EMA(diffusion_model, beta = ema_decay)
-        self.update_ema_every = update_ema_every
+        self.ema = EMA(diffusion_model, beta = ema_decay, update_every = ema_update_every)
 
         self.step_start_ema = step_start_ema
         self.save_and_sample_every = save_and_sample_every
